==> haskell-megaparsec-9.7.0-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 megaparsec
version:              9.7.0
visibility:           public
id:                   megaparsec-9.7.0-DoL2miG02BJ8XUb2sfozR5
key:                  megaparsec-9.7.0-DoL2miG02BJ8XUb2sfozR5
license:              BSD-2-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:
    Megaparsec contributors,
    Paolo Martini <paolo@nemail.it>,
    Daan Leijen <daan@microsoft.com>

homepage:             https://github.com/mrkkrp/megaparsec
synopsis:             Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that tries to find a nice balance
    between speed, flexibility, and quality of parse errors.

category:             Parsing
abi:                  f21c19aeea5f86194d7eb293f468cbec
exposed:              True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Binary
    Text.Megaparsec.Byte.Lexer Text.Megaparsec.Char
    Text.Megaparsec.Char.Lexer Text.Megaparsec.Debug
    Text.Megaparsec.Error Text.Megaparsec.Error.Builder
    Text.Megaparsec.Internal Text.Megaparsec.Pos Text.Megaparsec.State
    Text.Megaparsec.Stream Text.Megaparsec.Unicode

hidden-modules:
    Text.Megaparsec.Class Text.Megaparsec.Common Text.Megaparsec.Lexer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/megaparsec-9.7.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/megaparsec-9.7.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/megaparsec-9.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-megaparsec
hs-libraries:         HSmegaparsec-9.7.0-DoL2miG02BJ8XUb2sfozR5
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-GKEaqjX3nXNEZmMRebSTRD containers-0.6.7
    deepseq-1.4.8.0 mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav
    scientific-0.3.8.0-Lr1UPzAneM96vFGoFLDTYK text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-megaparsec/html/megaparsec.haddock
haddock-html:         /usr/share/doc/haskell-megaparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-megaparsec-9.7.0-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 megaparsec
version:              9.7.0
visibility:           public
id:                   megaparsec-9.7.0-2LveF0uKMovFZzLupvHuy3
key:                  megaparsec-9.7.0-2LveF0uKMovFZzLupvHuy3
license:              BSD-2-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:
    Megaparsec contributors,
    Paolo Martini <paolo@nemail.it>,
    Daan Leijen <daan@microsoft.com>

homepage:             https://github.com/mrkkrp/megaparsec
synopsis:             Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that tries to find a nice balance
    between speed, flexibility, and quality of parse errors.

category:             Parsing
abi:                  5a7094ce417b9dc11aa8c228013ecae4
exposed:              True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Binary
    Text.Megaparsec.Byte.Lexer Text.Megaparsec.Char
    Text.Megaparsec.Char.Lexer Text.Megaparsec.Debug
    Text.Megaparsec.Error Text.Megaparsec.Error.Builder
    Text.Megaparsec.Internal Text.Megaparsec.Pos Text.Megaparsec.State
    Text.Megaparsec.Stream Text.Megaparsec.Unicode

hidden-modules:
    Text.Megaparsec.Class Text.Megaparsec.Common Text.Megaparsec.Lexer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/megaparsec-9.7.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/megaparsec-9.7.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/megaparsec-9.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-megaparsec
hs-libraries:         HSmegaparsec-9.7.0-2LveF0uKMovFZzLupvHuy3
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-LsX0nU5KPAoJUeisZm5xEf containers-0.6.7
    deepseq-1.4.8.0 mtl-2.2.2
    parser-combinators-1.3.0-11YwG5dPNej79xqbn9HKav
    scientific-0.3.8.0-JrlaAXGfnydA9ZtLsuTElg text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-megaparsec/html/megaparsec.haddock
haddock-html:         /usr/share/doc/haskell-megaparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
